@@ -1,6 +1,4 @@
-import json
 import pytest
-
 from .dumper import dump_db
 from .utils import server_from_config, dbname_from_config, \
         maybe_destroy_and_create
@@ -15,10 +13,18 @@ def pytest_addhooks(pluginmanager):
     pluginmanager.addhooks(hookspec)
 
 def pytest_sessionstart(session):
-    server = server_from_config(session.config)
-    dbname = dbname_from_config(session.config, 'pytest_%s_couchapp_source')
-    #db = maybe_destroy_and_create(server, dbname)
-    session.config.hook.pytest_couchdbkit_push_app(server=server, dbname=dbname)
+    slaveinput = getattr(session.config, 'slaveinput', None)
+    if slaveinput is not None:
+        return
+    try:
+        dbname = dbname_from_config(session.config, 'pytest_%s_couchapp_source')
+    except pytest.xfail.Exception:
+        pass # we are not configured
+    else:
+        server = server_from_config(session.config)
+        session.config.hook.pytest_couchdbkit_push_app(
+                server=server,
+                dbname=dbname)
 
 def pytest_funcarg__couchdb_server(request):
     return server_from_config(request.config)
@@ -30,8 +36,10 @@ def pytest_funcarg__couchdb(request):
 
     dbname = dbname_from_config(request.config, 'pytest_%s')
     db_source = dbname_from_config(request.config, 'pytest_%s_couchapp_source')
+    slaveinput = getattr(request.config, 'slaveinput', None)
+    if slaveinput is not None:
+        dbname = '%s_%s' % (dbname, slaveinput['slaveid'])
     db = maybe_destroy_and_create(server, dbname)
-
     if db_source in server.all_dbs():
         server.replicate(db_source, dbname)
     
